@@ -3,7 +3,6 @@
 #' The \code{ContourLayer} renders contour lines for a given threshold and cell size.
 #' Internally it implements \href{https://en.wikipedia.org/wiki/Marching_squares}{Marching Squares} algorithm to generate contour line segments
 #' and feeds them into \code{LineLayer} to render lines.
-#'
 #' @inheritParams add_layer
 #' @seealso \url{https://deck.gl/#/documentation/deckgl-api-reference/layers/contour-layer}
 #' @example inst/examples/deckgl-api-reference/contour-layer.R
@@ -12,16 +11,16 @@ add_contour_layer <- function(deckgl, id = "contour-layer", data = NULL, propert
   add_layer(deckgl, "ContourLayer", id, data, properties, ...)
 }
 
-#' Use contour definition
+#' Create a contour definition
 #'
-#' @param threshold threshold value to be used in contour generation
-#' @param color RGB color array to be used to render contour lines
-#' @param strokeWidth width of the contour lines in pixels
+#' @param threshold The threshold value used in contour generation.
+#' @param color The RGB color array used to render contour lines.
+#' @param stroke_width The width of the contour lines in pixels.
 #' @export
-use_contour_definition <- function(threshold = 1, color = c(255, 255, 255), strokeWidth = 1) {
+use_contour_definition <- function(threshold = 1, color = c(255, 255, 255), stroke_width = 1) {
   list(
     threshold = threshold,
     color = color,
-    strokeWidth = strokeWidth
+    strokeWidth = stroke_width
   )
 }
