@@ -2,17 +2,20 @@
 data("bart_segments")
 
 properties <- list(
-  pickable = TRUE,
   getWidth = 12,
   getSourcePosition = ~from_lng + from_lat,
   getTargetPosition = ~to_lng + to_lat,
   getSourceColor = JS("d => [Math.sqrt(d.inbound), 140, 0]"),
   getTargetColor = JS("d => [Math.sqrt(d.outbound), 140, 0]"),
-  getTooltip = JS("object => `${object.from_name} to ${object.to_name}`")
+  tooltip = use_tooltip(
+    html = "{{from_name}} to {{to_name}}",
+    style = "background: steelBlue; border-radius: 5px;"
+  )
 )
 
 deck <- deckgl(zoom = 10, pitch = 35) %>%
   add_arc_layer(data = bart_segments, properties = properties) %>%
-  add_mapbox_basemap()
+  add_control("Arc Layer", "top-left") %>%
+  add_basemap()
 
 if (interactive()) deck
