@@ -12,8 +12,9 @@ deck <- deckgl(zoom = 11, pitch = 35) %>%
     elevationScale = 5000,
     radius = 250,
     extruded = TRUE,
-    getTooltip = JS("object => `height: ${object.value * 5000}m`")
+    tooltip = "Value: {{value}}"
   ) %>%
-  add_mapbox_basemap()
+  add_control("Column Layer", "bottom-left") %>%
+  add_basemap()
 
 if (interactive()) deck
